Class: DocxGenerator::Word::Document

Inherits:
Element
  • Object
show all
Defined in:
lib/docx_generator/word/base.rb

Overview

Represent the w:document element from Office Open XML specification. This class should not be used directly by the users of the library.

Instance Method Summary collapse

Methods inherited from Element

#add, #generate

Constructor Details

#initialize(attributes = {}, content = []) ⇒ Document

Create a new w:document element.

Parameters:

  • attributes (Hash) (defaults to: {})

    The attributes of the XML element. In the case of the w:document element, the only attribute should be w:conformance. If ommited, the value is transitional. If not, the two accepted values are strict and transitional.

  • content (Array) (defaults to: [])

    An array of the children of the XML element (other XML elements).



9
10
11
# File 'lib/docx_generator/word/base.rb', line 9

def initialize(attributes = {}, content = [])
  super("w:document", attributes, content)
end